==> ejc-budgetmanage-impl-3.0.0-20220328.024439-27-sources.jar: com/ejianc/business/bedget/bean/SubpackageEntity.java <==
package com.ejianc.business.bedget.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 分包施工图预算
 * 
 * @author generator
 * 
 */
 @TableName("ejc_budgetmanage_subpackage")
public class SubpackageEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="change_id")
    private java.lang.Long changeId; // 变更单据id
    @TableField(value="change_state")
    private java.lang.String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    @TableField(value="agent_id")
    private java.lang.Long agentId; // 经办人
    @TableField(value="agent_name")
    private java.lang.String agentName; // 经办人姓名
    @TableField(value="contract")
    private java.lang.Long contract; // 合同
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="subcontract_unit")
    private java.lang.Long subcontractUnit; // 分包单位
    @TableField(value="subcontract_unit_name")
    private java.lang.String subcontractUnitName; // 分包单位名称
    @TableField(value="excluding_tax_total")
    private java.math.BigDecimal excludingTaxTotal; // 除税合价合计
    @TableField(value="including_tax_total")
    private java.math.BigDecimal includingTaxTotal; // 含税合价合计
    @TableField(value="excluding_tax_unit_price_total")
    private java.math.BigDecimal excludingTaxUnitPriceTotal; // 除税单价合计
    @TableField(value="including_tax_unit_price_total")
    private java.math.BigDecimal includingTaxUnitPriceTotal; // 含税单价合计


    @TableField(exist=false)
    @SubEntity(serviceName="subpackagedetailService", pidName = "mid")
    private List<SubpackagedetailEntity> subpackagedetailEntities = new ArrayList<>(); // 分包施工图预算子表



    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 变更单据id
     */
    public java.lang.Long getChangeId() {
        return changeId;
    }

    /**
     * 变更单据id
     */
    public void setChangeId(java.lang.Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 经办人
     */
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人
     */
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人姓名
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人姓名
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }
    /**
     * 合同
     */
    public java.lang.Long getContract() {
        return contract;
    }

    /**
     * 合同
     */
    public void setContract(java.lang.Long contract) {
        this.contract = contract;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 分包单位
     */
    public java.lang.Long getSubcontractUnit() {
        return subcontractUnit;
    }

    /**
     * 分包单位
     */
    public void setSubcontractUnit(java.lang.Long subcontractUnit) {
        this.subcontractUnit = subcontractUnit;
    }
    /**
     * 分包单位名称
     */
    public java.lang.String getSubcontractUnitName() {
        return subcontractUnitName;
    }

    /**
     * 分包单位名称
     */
    public void setSubcontractUnitName(java.lang.String subcontractUnitName) {
        this.subcontractUnitName = subcontractUnitName;
    }
    /**
     * 除税合价合计
     */
    public java.math.BigDecimal getExcludingTaxTotal() {
        return excludingTaxTotal;
    }

    /**
     * 除税合价合计
     */
    public void setExcludingTaxTotal(java.math.BigDecimal excludingTaxTotal) {
        this.excludingTaxTotal = excludingTaxTotal;
    }
    /**
     * 含税合价合计
     */
    public java.math.BigDecimal getIncludingTaxTotal() {
        return includingTaxTotal;
    }

    /**
     * 含税合价合计
     */
    public void setIncludingTaxTotal(java.math.BigDecimal includingTaxTotal) {
        this.includingTaxTotal = includingTaxTotal;
    }
    /**
     * 除税单价合计
     */
    public java.math.BigDecimal getExcludingTaxUnitPriceTotal() {
        return excludingTaxUnitPriceTotal;
    }

    /**
     * 除税单价合计
     */
    public void setExcludingTaxUnitPriceTotal(java.math.BigDecimal excludingTaxUnitPriceTotal) {
        this.excludingTaxUnitPriceTotal = excludingTaxUnitPriceTotal;
    }
    /**
     * 含税单价合计
     */
    public java.math.BigDecimal getIncludingTaxUnitPriceTotal() {
        return includingTaxUnitPriceTotal;
    }

    /**
     * 含税单价合计
     */
    public void setIncludingTaxUnitPriceTotal(java.math.BigDecimal includingTaxUnitPriceTotal) {
        this.includingTaxUnitPriceTotal = includingTaxUnitPriceTotal;
    }
    /**
     * 分包施工图预算
     */
    public List<SubpackagedetailEntity> getSubpackagedetailEntities() {
        return subpackagedetailEntities;
    }
    /**
     * 分包施工图预算
     */
    public void setSubpackagedetailEntities(List<SubpackagedetailEntity> subpackagedetailEntities) {
        this.subpackagedetailEntities = subpackagedetailEntities;
    }


}

==> ejc-budgetmanage-impl-3.0.0-20220406.092419-64-sources.jar: com/ejianc/business/bedget/bean/SubpackageEntity.java <==
package com.ejianc.business.bedget.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 分包施工图预算
 * 
 * @author generator
 * 
 */
 @TableName("ejc_budgetmanage_subpackage")
public class SubpackageEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="change_id")
    private java.lang.Long changeId; // 变更单据id
    @TableField(value="change_state")
    private java.lang.String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    @TableField(value="agent_id")
    private java.lang.Long agentId; // 经办人
    @TableField(value="agent_name")
    private java.lang.String agentName; // 经办人姓名
    @TableField(value="contract")
    private java.lang.Long contract; // 合同
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="subcontract_unit")
    private java.lang.Long subcontractUnit; // 分包单位
    @TableField(value="subcontract_unit_name")
    private java.lang.String subcontractUnitName; // 分包单位名称
    @TableField(value="excluding_tax_total")
    private java.math.BigDecimal excludingTaxTotal; // 除税合价合计
    @TableField(value="including_tax_total")
    private java.math.BigDecimal includingTaxTotal; // 含税合价合计
    @TableField(value="excluding_tax_unit_price_total")
    private java.math.BigDecimal excludingTaxUnitPriceTotal; // 除税单价合计
    @TableField(value="including_tax_unit_price_total")
    private java.math.BigDecimal includingTaxUnitPriceTotal; // 含税单价合计
    @TableField(value="is_enable")
    private java.lang.Long isEnable; // 含税单价合计

    @TableField(exist=false)
    @SubEntity(serviceName="subpackagedetailService", pidName = "mid")
    private List<SubpackagedetailEntity> subpackagedetailEntities = new ArrayList<>(); // 分包施工图预算子表

    public Long getIsEnable() {
        return isEnable;
    }

    public void setIsEnable(Long isEnable) {
        this.isEnable = isEnable;
    }

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 变更单据id
     */
    public java.lang.Long getChangeId() {
        return changeId;
    }

    /**
     * 变更单据id
     */
    public void setChangeId(java.lang.Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 经办人
     */
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人
     */
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人姓名
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人姓名
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }
    /**
     * 合同
     */
    public java.lang.Long getContract() {
        return contract;
    }

    /**
     * 合同
     */
    public void setContract(java.lang.Long contract) {
        this.contract = contract;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 分包单位
     */
    public java.lang.Long getSubcontractUnit() {
        return subcontractUnit;
    }

    /**
     * 分包单位
     */
    public void setSubcontractUnit(java.lang.Long subcontractUnit) {
        this.subcontractUnit = subcontractUnit;
    }
    /**
     * 分包单位名称
     */
    public java.lang.String getSubcontractUnitName() {
        return subcontractUnitName;
    }

    /**
     * 分包单位名称
     */
    public void setSubcontractUnitName(java.lang.String subcontractUnitName) {
        this.subcontractUnitName = subcontractUnitName;
    }
    /**
     * 除税合价合计
     */
    public java.math.BigDecimal getExcludingTaxTotal() {
        return excludingTaxTotal;
    }

    /**
     * 除税合价合计
     */
    public void setExcludingTaxTotal(java.math.BigDecimal excludingTaxTotal) {
        this.excludingTaxTotal = excludingTaxTotal;
    }
    /**
     * 含税合价合计
     */
    public java.math.BigDecimal getIncludingTaxTotal() {
        return includingTaxTotal;
    }

    /**
     * 含税合价合计
     */
    public void setIncludingTaxTotal(java.math.BigDecimal includingTaxTotal) {
        this.includingTaxTotal = includingTaxTotal;
    }
    /**
     * 除税单价合计
     */
    public java.math.BigDecimal getExcludingTaxUnitPriceTotal() {
        return excludingTaxUnitPriceTotal;
    }

    /**
     * 除税单价合计
     */
    public void setExcludingTaxUnitPriceTotal(java.math.BigDecimal excludingTaxUnitPriceTotal) {
        this.excludingTaxUnitPriceTotal = excludingTaxUnitPriceTotal;
    }
    /**
     * 含税单价合计
     */
    public java.math.BigDecimal getIncludingTaxUnitPriceTotal() {
        return includingTaxUnitPriceTotal;
    }

    /**
     * 含税单价合计
     */
    public void setIncludingTaxUnitPriceTotal(java.math.BigDecimal includingTaxUnitPriceTotal) {
        this.includingTaxUnitPriceTotal = includingTaxUnitPriceTotal;
    }
    /**
     * 分包施工图预算
     */
    public List<SubpackagedetailEntity> getSubpackagedetailEntities() {
        return subpackagedetailEntities;
    }
    /**
     * 分包施工图预算
     */
    public void setSubpackagedetailEntities(List<SubpackagedetailEntity> subpackagedetailEntities) {
        this.subpackagedetailEntities = subpackagedetailEntities;
    }


}
